#include <Redis_Receiver.h>
using namespace inaf::oasbo::Receivers;

RedisReceiverBuilder::RedisReceiverBuilder() {
	this->reset();
}

RedisReceiverBuilder::RedisReceiverBuilder(std::string ip, int port, std::string key) {
	this->receiver = new RedisReceiver(ip, port, key);
}

RedisReceiverBuilder::~RedisReceiverBuilder() {
	delete receiver;
}

void RedisReceiverBuilder::reset() {
	this->receiver = new RedisReceiver();
}

RedisReceiverBuilder* RedisReceiverBuilder::configFrom(Configurators::BaseConfigurator &conf) {
	conf.readConfigFromSource(config_target);
	std::map<std::string, std::string> params = conf.getConfig();

	std::string key = config_target+"_"+ip_key;
	if (params.count(key) > 0){
		receiver->setIp(params[key]);
	}
	key = config_target+"_"+port_key;
	if (params.count(key) > 0){
		receiver->setPort(std::stoi(params[key]));
	}
	key = config_target+"_"+key_key;
	if (params.count(key) > 0){
		receiver->setKey(params[key]);
	}
	key = config_target+"_"+checkinterval_key;
	if (params.count(key) > 0){
		receiver->check_interval = std::stoi(params[key]);
	}
	return this;
}

RedisReceiverBuilder* RedisReceiverBuilder::setIp(std::string ip) {
	receiver->setIp(ip);
	return this;
}

RedisReceiverBuilder* RedisReceiverBuilder::setPort(int port) {
	receiver->setPort(port);
	return this;
}

RedisReceiverBuilder* RedisReceiverBuilder::setKey(std::string key) {
	receiver->setKey(key);
	return this;
}

RedisReceiver* RedisReceiverBuilder::getReceiver() {
	RedisReceiver *result = this->receiver;
	this->reset();
	return result;
}
